@@ -24,6 +24,7 @@
 #include "config.h"
 
 #include <cstring>
+#include <cstdlib>
 #include <limits>
 #include <locale.h>
 
@@ -35,6 +36,11 @@
 # include <mach-o/dyld.h> // for _NSGetExecutablePath()
 #endif
 
+#include <QCoreApplication>
+#include <QApplication>
+#include <QtGlobal>
+#include <QTextCodec>
+
 #include "gettext.h"
 #define _(string) gettext(string)
 
@@ -50,7 +56,6 @@
 #if HAVE_LIBLIRCCLIENT
 # include "lirc.h"
 #endif
-#include "qt_app.h"
 #include "lib_versions.h"
 
 
@@ -121,6 +126,25 @@ static const char *localedir()
 #endif
 }
 
+static void qt_msg_handler(QtMsgType type, const char *msg)
+{
+    switch (type)
+    {
+    case QtDebugMsg:
+        msg::dbg("%s", msg);
+        break;
+    case QtWarningMsg:
+        msg::wrn("%s", msg);
+        break;
+    case QtCriticalMsg:
+        msg::err("%s", msg);
+        break;
+    case QtFatalMsg:
+        msg::err("%s", msg);
+        std::abort();
+    }
+}
+
 int main(int argc, char *argv[])
 {
     /* Initialization: gettext */
@@ -136,6 +160,20 @@ int main(int argc, char *argv[])
     msg::set_columns_from_env();
     dbg::init_crashhandler();
 
+    /* Initialization: Qt */
+#ifdef Q_WS_X11
+    const char *display = getenv("DISPLAY");
+    bool have_display = (display && display[0] != '\0');
+#else
+    bool have_display = true;
+#endif
+    qInstallMsgHandler(qt_msg_handler);
+    QApplication *qt_app = new QApplication(argc, argv, have_display);
+    QTextCodec::setCodecForCStrings(QTextCodec::codecForLocale()); // necessary for i18n via gettext
+    QCoreApplication::setOrganizationName("Bino");
+    QCoreApplication::setOrganizationDomain("bino3d.org");
+    QCoreApplication::setApplicationName(PACKAGE_NAME);
+
     /* Command line handling */
     std::vector<opt::option *> options;
     opt::info help("help", '\0', opt::optional);
@@ -282,7 +320,6 @@ int main(int argc, char *argv[])
     {
         return 1;
     }
-    set_qt_argv(argc, argv);
     if (version.value())
     {
         msg::req(_("%s version %s"), PACKAGE_NAME, VERSION);
@@ -590,23 +627,30 @@ int main(int argc, char *argv[])
             throw exc(_("This version of Bino was compiled without support for Equalizer."));
 #endif
         }
-        else if (!no_gui.value())
-        {
-            if (log_level.value() == "")
-            {
-                init_data.log_level = msg::WRN;         // Be silent by default when the GUI is used
-            }
-            init_data.fullscreen = false;               // GUI overrides fullscreen setting
-            init_data.center = false;                   // GUI overrides center flag
-            player = new class player_qt();
-        }
         else
         {
-            if (arguments.size() == 0)
+            if (!have_display)
             {
-                throw exc(_("No video to play."));
+                throw exc(_("Cannot connect to X server."));
+            }
+            else if (!no_gui.value())
+            {
+                if (log_level.value() == "")
+                {
+                    init_data.log_level = msg::WRN;         // Be silent by default when the GUI is used
+                }
+                init_data.fullscreen = false;               // GUI overrides fullscreen setting
+                init_data.center = false;                   // GUI overrides center flag
+                player = new class player_qt();
+            }
+            else
+            {
+                if (arguments.size() == 0)
+                {
+                    throw exc(_("No video to play."));
+                }
+                player = new class player();
             }
-            player = new class player();
         }
         player->open(init_data);
         player->run();
@@ -626,5 +670,7 @@ int main(int argc, char *argv[])
     lirc.deinit();
 #endif
 
+    delete qt_app;
+
     return retval;
 }
