@@ -134,6 +134,7 @@ void video_output::deinit()
     {
         make_context_current();
         assert(xgl::CheckError(HERE));
+        clear();
         input_deinit(0);
         input_deinit(1);
         color_deinit();
@@ -404,6 +405,7 @@ void video_output::update_subtitle_tex(int index, const video_frame &frame, cons
     int height = 0;
     if (subtitle.is_valid())
     {
+        assert(_subtitle_renderer.is_initialized());
         if (_subtitle_renderer.render_to_display_size(subtitle))
         {
             width = video_display_width();
