@@ -30,6 +30,7 @@ static GLEWContext* glewGetContext() { return &_glewContext; }
 
 #include <cmath>
 #include <cstdlib>
+#include <unistd.h>
 
 #include <QApplication>
 #include <QDesktopWidget>
@@ -39,6 +40,8 @@ static GLEWContext* glewGetContext() { return &_glewContext; }
 #include <QMessageBox>
 #include <QPalette>
 #include <QProcess>
+#include <QDialog>
+#include <QLabel>
 #ifdef Q_WS_X11
 # include <QX11Info>
 # include <X11/Xlib.h>
@@ -51,8 +54,8 @@ static GLEWContext* glewGetContext() { return &_glewContext; }
 #include "msg.h"
 #include "str.h"
 #include "dbg.h"
+#include "timer.h"
 
-#include "qt_app.h"
 #include "video_output_qt.h"
 #include "lib_versions.h"
 
@@ -270,14 +273,12 @@ void video_container_widget::closeEvent(QCloseEvent *)
 
 video_output_qt::video_output_qt(bool benchmark, video_container_widget *container_widget) :
     video_output(),
-    _qt_app_owner(false),
     _container_widget(container_widget),
     _container_is_external(container_widget != NULL),
     _widget(NULL),
     _fullscreen(false),
     _playing(false)
 {
-    _qt_app_owner = init_qt();
     if (!_container_widget)
     {
         _container_widget = new video_container_widget(NULL);
@@ -297,10 +298,6 @@ video_output_qt::~video_output_qt()
     {
         delete _container_widget;
     }
-    if (_qt_app_owner)
-    {
-        exit_qt();
-    }
 }
 
 void video_output_qt::init()
@@ -329,6 +326,58 @@ void video_output_qt::init()
     }
 }
 
+int64_t video_output_qt::wait_for_subtitle_renderer()
+{
+    if (_subtitle_renderer.is_initialized())
+    {
+        return 0;
+    }
+    int64_t wait_start = timer::get_microseconds(timer::monotonic);
+    exc init_exception;
+    QDialog *mbox = NULL;
+    // Show a dialog only in GUI mode
+    if (_container_is_external && !_fullscreen)
+    {
+        mbox = new QDialog(_container_widget);
+        mbox->setModal(true);
+        mbox->setWindowTitle(_("Please wait"));
+        QGridLayout *mbox_layout = new QGridLayout;
+        QLabel *mbox_label = new QLabel(_("Waiting for subtitle renderer initialization..."));
+        mbox_layout->addWidget(mbox_label, 0, 0);
+        mbox->setLayout(mbox_layout);
+        mbox->show();
+    }
+    else
+    {
+        msg::wrn(_("Waiting for subtitle renderer initialization..."));
+    }
+    QApplication::setOverrideCursor(QCursor(Qt::WaitCursor));
+    try
+    {
+        while (!_subtitle_renderer.is_initialized())
+        {
+            process_events();
+            usleep(10000);
+        }
+    }
+    catch (std::exception &e)
+    {
+        init_exception = e;
+    }
+    QApplication::restoreOverrideCursor();
+    if (mbox)
+    {
+        mbox->hide();
+        delete mbox;
+    }
+    if (!init_exception.empty())
+    {
+        throw init_exception;
+    }
+    int64_t wait_stop = timer::get_microseconds(timer::monotonic);
+    return (wait_stop - wait_start);
+}
+
 void video_output_qt::deinit()
 {
     if (_widget)
@@ -610,6 +659,7 @@ void video_output_qt::enter_fullscreen(int screens)
             // would also require the window manager to support this extension...
             _container_widget->setWindowFlags(_container_widget->windowFlags()
                     | Qt::X11BypassWindowManagerHint
+                    | Qt::FramelessWindowHint
                     | Qt::WindowStaysOnTopHint);
             _container_widget->setWindowState(_widget->windowState() | Qt::WindowFullScreen);
             _container_widget->setGeometry(geom);
@@ -625,8 +675,8 @@ void video_output_qt::enter_fullscreen(int screens)
             XSetInputFocus(QX11Info::display(), _container_widget->winId(), RevertToParent, CurrentTime);
             XFlush(QX11Info::display());
 #endif
-            grab_focus();
         }
+        grab_focus();
         // Suspend the screensaver after going fullscreen, so that our window ID
         // represents the fullscreen window. We need to have the same ID for resume.
         suspend_screensaver();
@@ -660,6 +710,7 @@ void video_output_qt::exit_fullscreen()
         }
         _container_widget->setWindowFlags(_container_widget->windowFlags()
                 & ~Qt::X11BypassWindowManagerHint
+                & ~Qt::FramelessWindowHint
                 & ~Qt::WindowStaysOnTopHint);
         _container_widget->setWindowState(_widget->windowState() & ~Qt::WindowFullScreen);
         _container_widget->setCursor(Qt::ArrowCursor);
